/*******************************************************************************
* File Name: TimerStripLightsRefresh50Hz.c  
* Version 3.0
*
*  Description:
*     The Counter component consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerStripLightsRefresh50Hz.h"

uint8 TimerStripLightsRefresh50Hz_initVar = 0u;


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Init(void) 
{
        #if (!TimerStripLightsRefresh50Hz_UsingFixedFunction && !TimerStripLightsRefresh50Hz_ControlRegRemoved)
            uint8 ctrl;
        #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction && !TimerStripLightsRefresh50Hz_ControlRegRemoved) */
        
        #if(!TimerStripLightsRefresh50Hz_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 TimerStripLightsRefresh50Hz_interruptState;
        #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */
        
        #if (TimerStripLightsRefresh50Hz_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            TimerStripLightsRefresh50Hz_CONTROL &= TimerStripLightsRefresh50Hz_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (CY_PSOC5A)
                TimerStripLightsRefresh50Hz_CONTROL2 &= ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_MODE_MASK));
            #endif /* (CY_PSOC5A) */
            #if (CY_PSOC3 || CY_PSOC5LP)
                TimerStripLightsRefresh50Hz_CONTROL3 &= ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_MODE_MASK));                
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (TimerStripLightsRefresh50Hz_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                TimerStripLightsRefresh50Hz_CONTROL |= TimerStripLightsRefresh50Hz_ONESHOT;
            #endif /* (TimerStripLightsRefresh50Hz_RunModeUsed != 0x0u) */
            
            /* Set the IRQ to use the status register interrupts */
            TimerStripLightsRefresh50Hz_CONTROL2 |= TimerStripLightsRefresh50Hz_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            TimerStripLightsRefresh50Hz_RT1 &= ((uint8)(~TimerStripLightsRefresh50Hz_RT1_MASK));
            TimerStripLightsRefresh50Hz_RT1 |= TimerStripLightsRefresh50Hz_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            TimerStripLightsRefresh50Hz_RT1 &= ((uint8)(~TimerStripLightsRefresh50Hz_SYNCDSI_MASK));
            TimerStripLightsRefresh50Hz_RT1 |= TimerStripLightsRefresh50Hz_SYNCDSI_EN;

        #else
            #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = TimerStripLightsRefresh50Hz_CONTROL & ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_CMPMODE_MASK));
            TimerStripLightsRefresh50Hz_CONTROL = ctrl | TimerStripLightsRefresh50Hz_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = TimerStripLightsRefresh50Hz_CONTROL & ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_CAPMODE_MASK));
            
            #if( 0 != TimerStripLightsRefresh50Hz_CAPTURE_MODE_CONF)
                TimerStripLightsRefresh50Hz_CONTROL = ctrl | TimerStripLightsRefresh50Hz_DEFAULT_CAPTURE_MODE;
            #else
                TimerStripLightsRefresh50Hz_CONTROL = ctrl;
            #endif /* 0 != TimerStripLightsRefresh50Hz_CAPTURE_MODE */ 
            
            #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */
        #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
        
        /* Clear all data in the FIFO's */
        #if (!TimerStripLightsRefresh50Hz_UsingFixedFunction)
            TimerStripLightsRefresh50Hz_ClearFIFO();
        #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */
        
        /* Set Initial values from Configuration */
        TimerStripLightsRefresh50Hz_WritePeriod(TimerStripLightsRefresh50Hz_INIT_PERIOD_VALUE);
        #if (!(TimerStripLightsRefresh50Hz_UsingFixedFunction && (CY_PSOC5A)))
            TimerStripLightsRefresh50Hz_WriteCounter(TimerStripLightsRefresh50Hz_INIT_COUNTER_VALUE);
        #endif /* (!(TimerStripLightsRefresh50Hz_UsingFixedFunction && (CY_PSOC5A))) */
        TimerStripLightsRefresh50Hz_SetInterruptMode(TimerStripLightsRefresh50Hz_INIT_INTERRUPTS_MASK);
        
        #if (!TimerStripLightsRefresh50Hz_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            (void)TimerStripLightsRefresh50Hz_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            TimerStripLightsRefresh50Hz_WriteCompare(TimerStripLightsRefresh50Hz_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            TimerStripLightsRefresh50Hz_interruptState = CyEnterCriticalSection();
            
            TimerStripLightsRefresh50Hz_STATUS_AUX_CTRL |= TimerStripLightsRefresh50Hz_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(TimerStripLightsRefresh50Hz_interruptState);
            
        #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (TimerStripLightsRefresh50Hz_UsingFixedFunction)
        TimerStripLightsRefresh50Hz_GLOBAL_ENABLE |= TimerStripLightsRefresh50Hz_BLOCK_EN_MASK;
        TimerStripLightsRefresh50Hz_GLOBAL_STBY_ENABLE |= TimerStripLightsRefresh50Hz_BLOCK_STBY_EN_MASK;
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */  
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved || TimerStripLightsRefresh50Hz_UsingFixedFunction)
        TimerStripLightsRefresh50Hz_CONTROL |= TimerStripLightsRefresh50Hz_CTRL_ENABLE;                
    #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved || TimerStripLightsRefresh50Hz_UsingFixedFunction) */
    
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  TimerStripLightsRefresh50Hz_initVar: Is modified when this function is called for the  
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Start(void) 
{
    if(TimerStripLightsRefresh50Hz_initVar == 0u)
    {
        TimerStripLightsRefresh50Hz_Init();
        
        TimerStripLightsRefresh50Hz_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    TimerStripLightsRefresh50Hz_Enable();        
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Stop(void) 
{
    /* Disable Counter */
    #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved || TimerStripLightsRefresh50Hz_UsingFixedFunction)
        TimerStripLightsRefresh50Hz_CONTROL &= ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_ENABLE));        
    #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved || TimerStripLightsRefresh50Hz_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (TimerStripLightsRefresh50Hz_UsingFixedFunction)
        TimerStripLightsRefresh50Hz_GLOBAL_ENABLE &= ((uint8)(~TimerStripLightsRefresh50Hz_BLOCK_EN_MASK));
        TimerStripLightsRefresh50Hz_GLOBAL_STBY_ENABLE &= ((uint8)(~TimerStripLightsRefresh50Hz_BLOCK_STBY_EN_MASK));
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_SetInterruptMode(uint8 interruptsMask) 
{
    TimerStripLightsRefresh50Hz_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
*******************************************************************************/
uint8   TimerStripLightsRefresh50Hz_ReadStatusRegister(void) 
{
    return TimerStripLightsRefresh50Hz_STATUS;
}


#if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
uint8   TimerStripLightsRefresh50Hz_ReadControlRegister(void) 
{
    return TimerStripLightsRefresh50Hz_CONTROL;
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
void    TimerStripLightsRefresh50Hz_WriteControlRegister(uint8 control) 
{
    TimerStripLightsRefresh50Hz_CONTROL = control;
}

#endif  /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */


#if (!(TimerStripLightsRefresh50Hz_UsingFixedFunction && (CY_PSOC5A)))
/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_WriteCounter(uint8 counter) \
                                   
{
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        /* assert if block is already enabled */
        CYASSERT (0u == (TimerStripLightsRefresh50Hz_GLOBAL_ENABLE & TimerStripLightsRefresh50Hz_BLOCK_EN_MASK));
        /* If block is disabled, enable it and then write the counter */
        TimerStripLightsRefresh50Hz_GLOBAL_ENABLE |= TimerStripLightsRefresh50Hz_BLOCK_EN_MASK;
        CY_SET_REG16(TimerStripLightsRefresh50Hz_COUNTER_LSB_PTR, (uint16)counter);
        TimerStripLightsRefresh50Hz_GLOBAL_ENABLE &= ((uint8)(~TimerStripLightsRefresh50Hz_BLOCK_EN_MASK));
    #else
        CY_SET_REG8(TimerStripLightsRefresh50Hz_COUNTER_LSB_PTR, counter);
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}
#endif /* (!(TimerStripLightsRefresh50Hz_UsingFixedFunction && (CY_PSOC5A))) */


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) The present value of the counter.
*
*******************************************************************************/
uint8 TimerStripLightsRefresh50Hz_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
		(void)CY_GET_REG16(TimerStripLightsRefresh50Hz_COUNTER_LSB_PTR);
	#else
		(void)CY_GET_REG8(TimerStripLightsRefresh50Hz_COUNTER_LSB_PTR_8BIT);
	#endif/* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(TimerStripLightsRefresh50Hz_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(TimerStripLightsRefresh50Hz_STATICCOUNT_LSB_PTR));
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) Present Capture value.
*
*******************************************************************************/
uint8 TimerStripLightsRefresh50Hz_ReadCapture(void) 
{
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(TimerStripLightsRefresh50Hz_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(TimerStripLightsRefresh50Hz_STATICCOUNT_LSB_PTR));
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint8) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_WritePeriod(uint8 period) 
{
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        CY_SET_REG16(TimerStripLightsRefresh50Hz_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG8(TimerStripLightsRefresh50Hz_PERIOD_LSB_PTR, period);
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) Present period value.
*
*******************************************************************************/
uint8 TimerStripLightsRefresh50Hz_ReadPeriod(void) 
{
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(TimerStripLightsRefresh50Hz_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(TimerStripLightsRefresh50Hz_PERIOD_LSB_PTR));
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


#if (!TimerStripLightsRefresh50Hz_UsingFixedFunction)
/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_WriteCompare(uint8 compare) \
                                   
{
    #if(TimerStripLightsRefresh50Hz_UsingFixedFunction)
        CY_SET_REG16(TimerStripLightsRefresh50Hz_COMPARE_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG8(TimerStripLightsRefresh50Hz_COMPARE_LSB_PTR, compare);
    #endif /* (TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint8) Present compare value.
*
*******************************************************************************/
uint8 TimerStripLightsRefresh50Hz_ReadCompare(void) 
{
    return (CY_GET_REG8(TimerStripLightsRefresh50Hz_COMPARE_LSB_PTR));
}


#if (TimerStripLightsRefresh50Hz_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    TimerStripLightsRefresh50Hz_CONTROL &= ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_CMPMODE_MASK));
    
    /* Write the new setting */
    TimerStripLightsRefresh50Hz_CONTROL |= compareMode;
}
#endif  /* (TimerStripLightsRefresh50Hz_COMPARE_MODE_SOFTWARE) */


#if (TimerStripLightsRefresh50Hz_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    TimerStripLightsRefresh50Hz_CONTROL &= ((uint8)(~TimerStripLightsRefresh50Hz_CTRL_CAPMODE_MASK));
    
    /* Write the new setting */
    TimerStripLightsRefresh50Hz_CONTROL |= ((uint8)((uint8)captureMode << TimerStripLightsRefresh50Hz_CTRL_CAPMODE0_SHIFT));
}
#endif  /* (TimerStripLightsRefresh50Hz_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_ClearFIFO(void) 
{

    while(0u != (TimerStripLightsRefresh50Hz_ReadStatusRegister() & TimerStripLightsRefresh50Hz_STATUS_FIFONEMP))
    {
        (void)TimerStripLightsRefresh50Hz_ReadCapture();
    }

}
#endif  /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */


/* [] END OF FILE */

