/*******************************************************************************
* File Name: TimerStripLightsRefresh50Hz_PM.c  
* Version 3.0
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerStripLightsRefresh50Hz.h"

static TimerStripLightsRefresh50Hz_backupStruct TimerStripLightsRefresh50Hz_backup;


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  TimerStripLightsRefresh50Hz_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_SaveConfig(void) 
{
    #if (!TimerStripLightsRefresh50Hz_UsingFixedFunction)

        TimerStripLightsRefresh50Hz_backup.CounterUdb = TimerStripLightsRefresh50Hz_ReadCounter();

        #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
            TimerStripLightsRefresh50Hz_backup.CounterControlRegister = TimerStripLightsRefresh50Hz_ReadControlRegister();
        #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */

    #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  TimerStripLightsRefresh50Hz_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_RestoreConfig(void) 
{      
    #if (!TimerStripLightsRefresh50Hz_UsingFixedFunction)

       TimerStripLightsRefresh50Hz_WriteCounter(TimerStripLightsRefresh50Hz_backup.CounterUdb);

        #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
            TimerStripLightsRefresh50Hz_WriteControlRegister(TimerStripLightsRefresh50Hz_backup.CounterControlRegister);
        #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */

    #endif /* (!TimerStripLightsRefresh50Hz_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  TimerStripLightsRefresh50Hz_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Sleep(void) 
{
    #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
        /* Save Counter's enable state */
        if(TimerStripLightsRefresh50Hz_CTRL_ENABLE == (TimerStripLightsRefresh50Hz_CONTROL & TimerStripLightsRefresh50Hz_CTRL_ENABLE))
        {
            /* Counter is enabled */
            TimerStripLightsRefresh50Hz_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            TimerStripLightsRefresh50Hz_backup.CounterEnableState = 0u;
        }
    #else
        TimerStripLightsRefresh50Hz_backup.CounterEnableState = 1u;
        if(TimerStripLightsRefresh50Hz_backup.CounterEnableState != 0u)
        {
            TimerStripLightsRefresh50Hz_backup.CounterEnableState = 0u;
        }
    #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */
    
    TimerStripLightsRefresh50Hz_Stop();
    TimerStripLightsRefresh50Hz_SaveConfig();
}


/*******************************************************************************
* Function Name: TimerStripLightsRefresh50Hz_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  TimerStripLightsRefresh50Hz_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void TimerStripLightsRefresh50Hz_Wakeup(void) 
{
    TimerStripLightsRefresh50Hz_RestoreConfig();
    #if(!TimerStripLightsRefresh50Hz_ControlRegRemoved)
        if(TimerStripLightsRefresh50Hz_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            TimerStripLightsRefresh50Hz_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!TimerStripLightsRefresh50Hz_ControlRegRemoved) */
    
}


/* [] END OF FILE */
