/* ========================================
 *
 * Optional for demonstration purpose only: 
 * RGB LEDs based on WS2812 type are used for
 * 1. Display the color meausured by the sensor
 * 2. Some fancy rotating while snsor is not active
 *
 * by Holger Wech, 05/2018
 *
 * ========================================
*/

#include <project.h>
#include "WS2812.h"

#define NEO_TEST_DELAY (200u) //!< used while NeoPixel test (input 'n') as delay between pattern

volatile  uint32_t u32DelayDemoMode;    // delay befor running striplight demo, start demo if 0 
extern uint8 flagContd;

/** 
 * TimerStripLightsRefresh50Hz interrupt service 
 *
 * Trigger the Striplights\NeoPixel\WS2812B) each 20ms to update LED display
 */
CY_ISR(isr_TimerStripLightsRefresh50Hz)
{
	/* Read Status register in order to clear the sticky Terminal Count (TC) bit 
	 * in the status register. Note that the function is not called, but rather 
	 * the status is read directly.
	 */
   	TimerStripLightsRefresh50Hz_STATUS;
    
	StripLights_Trigger(1);   // Update the LED display
}

/** 
 * SysTick Timer interrupt service 
 *
 * In this example the timer is just use for some fancy output on the optional WS2812 LEDs
 * It has no relevance for RGB sensor example
 * Perdiodically called each 100ms (based on NUMBER_OF_TICKS)
 * @see NUMBER_OF_TICKS
 */

#define NUMBER_OF_TICKS		 (2400000u) // based 24MHz -> 2400000 -> 100ms interrupts

CY_ISR(mySystick_ISR)
{     
    if (u32DelayDemoMode)
    {
        u32DelayDemoMode = u32DelayDemoMode - 1;    
    }
    else
    {
        if (0 == flagContd)
            showWS2812(1);    
    }
}

/** @brief Do some activity on StripLigt/NeoPixel/WS2812B */
void showWS2812(uint8_t mode)
{
    static uint8_t i;
    
    switch (mode)
    {
        case 1 : // rotate white pixels
            switch(i%6)
            {
                case 0:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00808080); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g       
                    break;

                case 1:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00808080); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
                    break;
                    
                case 2:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00808080); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
                    break; 
                    
                case 3:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00808080); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
                    break;     
                    
                case 4:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00808080); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
                    break;       
                    
                case 5:
                    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
                    StripLights_Pixel( 6,0, 0x00808080); // - - b b r r g g 
                    break;  
                    
            } // switch(i%2)
            i = i + 1; // next pattern
            break;
        
        case 2 : // rotate RGB
            for (i=0; i<9; i++)
            {
                switch(i%3)
                {
                    case 0:
                        StripLights_Pixel( 0,0, 0x00808080); // - - b b r r g g 
                        StripLights_Pixel( 1,0, 0x00008000); // - - b b r r g g 
                        StripLights_Pixel( 2,0, 0x00000080); // - - b b r r g g 
                        StripLights_Pixel( 3,0, 0x00800000); // - - b b r r g g 
                        StripLights_Pixel( 4,0, 0x00008000); // - - b b r r g g 
                        StripLights_Pixel( 5,0, 0x00000080); // - - b b r r g g 
                        StripLights_Pixel( 6,0, 0x00800000); // - - b b r r g g       
                        break;

                    case 1:
                        StripLights_Pixel( 0,0, 0x00808080); // - - b b r r g g 
                        StripLights_Pixel( 1,0, 0x00800000); // - - b b r r g g 
                        StripLights_Pixel( 2,0, 0x00008000); // - - b b r r g g 
                        StripLights_Pixel( 3,0, 0x00000080); // - - b b r r g g 
                        StripLights_Pixel( 4,0, 0x00800000); // - - b b r r g g 
                        StripLights_Pixel( 5,0, 0x00008000); // - - b b r r g g 
                        StripLights_Pixel( 6,0, 0x00000080); // - - b b r r g g 
                        break;

                    case 2:
                        StripLights_Pixel( 0,0, 0x00808080); // - - b b r r g g 
                        StripLights_Pixel( 1,0, 0x00000080); // - - b b r r g g 
                        StripLights_Pixel( 2,0, 0x00800000); // - - b b r r g g 
                        StripLights_Pixel( 3,0, 0x00008000); // - - b b r r g g 
                        StripLights_Pixel( 4,0, 0x00000080); // - - b b r r g g 
                        StripLights_Pixel( 5,0, 0x00800000); // - - b b r r g g 
                        StripLights_Pixel( 6,0, 0x00008000); // - - b b r r g g 
                        break;
                } // switch(i%3)
                CyDelay(100);
            } //for 
    } // switch (mode)
}

/**
 * Static test of StripLights (not using the state machine)
 * 
 * @param none
 */
void testWS2812()
{
    StripLights_MemClear(StripLights_BLACK);
    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 0,0, 0x00008800); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00008800); // - - b b r r g g 
    StripLights_Trigger(1); 
    CyDelay(NEO_TEST_DELAY);
    
    StripLights_Pixel( 6,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 0,0, 0x00000088); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);

    StripLights_Pixel( 0,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00880000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);

    StripLights_Pixel( 0,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00FFFFFF); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);

    StripLights_Pixel( 0,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00FFFFFF); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);

    StripLights_Pixel( 0,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00000000); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_Pixel( 0,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 2,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 4,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 6,0, 0x00000000); // - - b b r r g g 
    StripLights_Pixel( 1,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 3,0, 0x00FFFFFF); // - - b b r r g g 
    StripLights_Pixel( 5,0, 0x00FFFFFF); // - - b b r r g g 
    CyDelay(NEO_TEST_DELAY);
    StripLights_MemClear(StripLights_BLACK);
}

/**
 * Starts the refresh timer for updating regularly the StripLights
 * 
 * @param none
 */
void initWS2812(void)
{
    StripLights_Start();
    StripLights_MemClear(StripLights_BLACK);
    StripLights_Dim(2); // Set dim level 0 = full power, 4 = lowest power
    
    // Refresh Timer
    irq_TimerStripLightsRefresh50Hz_StartEx(isr_TimerStripLightsRefresh50Hz);
    TimerStripLightsRefresh50Hz_Start();
    
     // SysTick (used for delays while running the fancy striplight demo)
    CyIntSetSysVector((SysTick_IRQn + 16), mySystick_ISR); /**< Map systick ISR to the user defined ISR. SysTick_IRQn is already defined in core_cm0.h file */
    SysTick_Config(NUMBER_OF_TICKS); /**< Enable Systick timer with desired period/number of ticks, e.g. 12000 */
}
/* [] END OF FILE */
