/*******************************************************************************
* File Name: WS2812B.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_WS2812B_H) /* Pins WS2812B_H */
#define CY_PINS_WS2812B_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "WS2812B_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 WS2812B__PORT == 15 && ((WS2812B__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    WS2812B_Write(uint8 value);
void    WS2812B_SetDriveMode(uint8 mode);
uint8   WS2812B_ReadDataReg(void);
uint8   WS2812B_Read(void);
void    WS2812B_SetInterruptMode(uint16 position, uint16 mode);
uint8   WS2812B_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the WS2812B_SetDriveMode() function.
     *  @{
     */
        #define WS2812B_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define WS2812B_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define WS2812B_DM_RES_UP          PIN_DM_RES_UP
        #define WS2812B_DM_RES_DWN         PIN_DM_RES_DWN
        #define WS2812B_DM_OD_LO           PIN_DM_OD_LO
        #define WS2812B_DM_OD_HI           PIN_DM_OD_HI
        #define WS2812B_DM_STRONG          PIN_DM_STRONG
        #define WS2812B_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define WS2812B_MASK               WS2812B__MASK
#define WS2812B_SHIFT              WS2812B__SHIFT
#define WS2812B_WIDTH              1u

/* Interrupt constants */
#if defined(WS2812B__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in WS2812B_SetInterruptMode() function.
     *  @{
     */
        #define WS2812B_INTR_NONE      (uint16)(0x0000u)
        #define WS2812B_INTR_RISING    (uint16)(0x0001u)
        #define WS2812B_INTR_FALLING   (uint16)(0x0002u)
        #define WS2812B_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define WS2812B_INTR_MASK      (0x01u) 
#endif /* (WS2812B__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define WS2812B_PS                     (* (reg8 *) WS2812B__PS)
/* Data Register */
#define WS2812B_DR                     (* (reg8 *) WS2812B__DR)
/* Port Number */
#define WS2812B_PRT_NUM                (* (reg8 *) WS2812B__PRT) 
/* Connect to Analog Globals */                                                  
#define WS2812B_AG                     (* (reg8 *) WS2812B__AG)                       
/* Analog MUX bux enable */
#define WS2812B_AMUX                   (* (reg8 *) WS2812B__AMUX) 
/* Bidirectional Enable */                                                        
#define WS2812B_BIE                    (* (reg8 *) WS2812B__BIE)
/* Bit-mask for Aliased Register Access */
#define WS2812B_BIT_MASK               (* (reg8 *) WS2812B__BIT_MASK)
/* Bypass Enable */
#define WS2812B_BYP                    (* (reg8 *) WS2812B__BYP)
/* Port wide control signals */                                                   
#define WS2812B_CTL                    (* (reg8 *) WS2812B__CTL)
/* Drive Modes */
#define WS2812B_DM0                    (* (reg8 *) WS2812B__DM0) 
#define WS2812B_DM1                    (* (reg8 *) WS2812B__DM1)
#define WS2812B_DM2                    (* (reg8 *) WS2812B__DM2) 
/* Input Buffer Disable Override */
#define WS2812B_INP_DIS                (* (reg8 *) WS2812B__INP_DIS)
/* LCD Common or Segment Drive */
#define WS2812B_LCD_COM_SEG            (* (reg8 *) WS2812B__LCD_COM_SEG)
/* Enable Segment LCD */
#define WS2812B_LCD_EN                 (* (reg8 *) WS2812B__LCD_EN)
/* Slew Rate Control */
#define WS2812B_SLW                    (* (reg8 *) WS2812B__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define WS2812B_PRTDSI__CAPS_SEL       (* (reg8 *) WS2812B__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define WS2812B_PRTDSI__DBL_SYNC_IN    (* (reg8 *) WS2812B__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define WS2812B_PRTDSI__OE_SEL0        (* (reg8 *) WS2812B__PRTDSI__OE_SEL0) 
#define WS2812B_PRTDSI__OE_SEL1        (* (reg8 *) WS2812B__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define WS2812B_PRTDSI__OUT_SEL0       (* (reg8 *) WS2812B__PRTDSI__OUT_SEL0) 
#define WS2812B_PRTDSI__OUT_SEL1       (* (reg8 *) WS2812B__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define WS2812B_PRTDSI__SYNC_OUT       (* (reg8 *) WS2812B__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(WS2812B__SIO_CFG)
    #define WS2812B_SIO_HYST_EN        (* (reg8 *) WS2812B__SIO_HYST_EN)
    #define WS2812B_SIO_REG_HIFREQ     (* (reg8 *) WS2812B__SIO_REG_HIFREQ)
    #define WS2812B_SIO_CFG            (* (reg8 *) WS2812B__SIO_CFG)
    #define WS2812B_SIO_DIFF           (* (reg8 *) WS2812B__SIO_DIFF)
#endif /* (WS2812B__SIO_CFG) */

/* Interrupt Registers */
#if defined(WS2812B__INTSTAT)
    #define WS2812B_INTSTAT            (* (reg8 *) WS2812B__INTSTAT)
    #define WS2812B_SNAP               (* (reg8 *) WS2812B__SNAP)
    
	#define WS2812B_0_INTTYPE_REG 		(* (reg8 *) WS2812B__0__INTTYPE)
#endif /* (WS2812B__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_WS2812B_H */


/* [] END OF FILE */
